@@ -1,14 +1,10 @@
 class Solution(object):
     def canJump(self, nums):
-        """
-        :type nums: List[int]
-        :rtype: bool
-        """
-        # greedy
-        # https://leetcode.com/articles/jump-game/
         length = len(nums)
         begin = length - 1
+        # 4，3，2，1，0
         for i in reversed(range(length - 1)):
             if i + nums[i] >= begin:
                 begin = i
+        # begin == 0 : return True
         return not begin
\ No newline at end of file
