@@ -1,13 +1,11 @@
+
 class Solution(object):
     def minPathSum(self, grid):
-        """
-        :type grid: List[List[int]]
-        :rtype: int
-        """
         height = len(grid)
         if height == 0:
             return 0
         width = len(grid[0])
+        # height x width
         pathmap = []
         for i in range(height):
             pathmap.append([100000000000] * width)
@@ -16,9 +14,11 @@ class Solution(object):
             for j in range(width):
                 compare = [pathmap[i][j]]
                 if i - 1 >= 0:
+                    # up
                     compare.append(pathmap[i - 1][j] + grid[i][j])
                 if j - 1 >= 0:
+                    # left
                     compare.append(pathmap[i][j - 1] + grid[i][j])
-                # min choice
+                # min choice，得到从i,j走到x,y的最小路径和
                 pathmap[i][j] = min(compare)
         return pathmap[-1][-1]
\ No newline at end of file
