@@ -18,13 +18,24 @@ class Solution:
                 root = root.right
 
         return result
+    def inorderTraversal2(self, root):
+        res =[]
+        s = []
+        p = root
+        while p or s!=[]:
+            while p:
+                s.append(p)
+                p = p.left
+            p = s.pop()
+            res.append(p.val)
+            p = p.right
+        return res;
 
 
 # 2递归版
 class Solution:
-
     def inorderTraversal(self, root):
         if root is None:
             return []
         else:
-            return [root.val] + self.inorderTraversal(root.left) +self.inorderTraversal(root.right)
+            return self.inorderTraversal(root.left) +[root.val]+self.inorderTraversal(root.right)
