@@ -1,11 +1,5 @@
 class Solution(object):
     def isInterleave(self, s1, s2, s3):
-        """
-        :type s1: str
-        :type s2: str
-        :type s3: str
-        :rtype: bool
-        """
         if len(s1) + len(s2) != len(s3):
             return False
         queue = [(0, 0), (-1, -1)]
