@@ -1,4 +1,3 @@
-
 class TreeNode(object):
     def __init__(self, x):
         self.val = x
@@ -8,14 +7,15 @@ class TreeNode(object):
 
 class Solution(object):
     # 借助队列
-    def levelOrder(self, root: TreeNode):
+    def levelOrder(self, root):
         res = []
         if not root: return res
 
         q = [root]
         while q != []:
             rs = []
-            for i in range(len(q)):
+            size=len(q)
+            for i in range(size):
                 first = q[0]
                 q.remove(first)
                 rs.append(first.val)
