@@ -1,4 +1,3 @@
-
 class Solution:
 
     def singleNumberIII(self, A):
@@ -30,9 +29,11 @@ class Solution:
 
 由于除了x1和x2之外其他数都是成对出现，故与最低位的1异或时一定会抵消，
 因此找到的第一个最低位的1，就是x1 x2中的某一个的
-最低位的1提取出来:在这一二进制位上x1和x2必然相异（1111,1110总得不一样，不然x^y=0）
-
+最低位的1提取出来:在这一二进制位上x1和x2必然相异（101111,111110  010001总得不一样，不然x^y=0）
 
+00110 
+00110 - (00110 &(00110 -1) )
+00110  -(00110 &00101 = 00100)=00010
 '''
 s = Solution()
 print(s.singleNumberIII([1, 2, 2, 3, 4, 4, 5, 3]))
