@@ -1,7 +1,6 @@
-
-
 class Solution1:
     def hashCode(self, key, HASH_SIZE):
+		# 原始方法
         if key == None or len(key) == 0: return -1;
         hashSum = 0
         for i in range(len(key)):
@@ -11,6 +10,7 @@ class Solution1:
 
 class Solution:
     def hashCode(self, key, HASH_SIZE):
+		# 快速方法
         if key == None or len(key) == 0: return -1;
         hashSum = 0
         for i in range(len(key)):
@@ -22,25 +22,11 @@ class Solution:
 
 
 '''
-不必要总数算得那么大了，再最后取模！。
-最终总数和是：1xxx无穷个0xxx 8 % 10 = 8，
-和每次总数涨一点点，就尝试 xi % 10 不一样吗
- (2+3+4+5) % 2 = 14 % 2=0 和 ((((((2 %2 =0）+3) %2 =1) +4 )%2=1) + 5)%2 =0
-
-
-输入:  key = "abcd", size = 1000
-输出: 97
-样例解释：(97 * 33^3 + 98*33^2 + 99*33 + 100*1)%1000 = 978
-        (33 * 0 + 97)    %100 = 97
-        (97 * 33 + 98)   %100 = 
-        (((97 * 33 + 98)   %100) * 33 + 99)   % 100 = 97*33^2 % 100 + 98*33 % 100 + 99 % 100 
-        (((97 * 33 + 98)   %100) % 100 * (33 %100) + 99 %100)   % 100 = 
-
 (a+b) % p =((a % p)+(b % p))% p
 '''
 
-s = Solution()  # 直接计算，缺点，计算量大
-s2 = Solution()
+s = Solution()  # 直接计算，缺点，计算量大，可能溢出
+s2 = Solution() # 每步取模，一直控制数据在很小的范围内。
 
 print(s.hashCode(key="abcd", HASH_SIZE=1000))
 print(s2.hashCode(key="abcd", HASH_SIZE=1000))
